==> react-atom-video-player-1.20.0.tgz: package/lib/components/HLSPlayer.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["autoPlay", "controls", "muted", "onLoadVideo", "hlsConfig", "timeLimit", "timeOffset", "playerRef", "src", "title"];
import { createRef } from 'react';
import Hls from 'hls.js';
import PropTypes from 'prop-types';
import useInitHlsEffect from '../hooks/hls/useInitHlsEffect.js';
import useTimeLimitCheck from '../hooks/hls/useTimeLimitCheck.js';
import { BASE_CLASS, HLS_DEFAULT_TITLE } from '../settings/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
var HLSPlayer = function HLSPlayer(_ref) {
  var autoPlay = _ref.autoPlay,
    controls = _ref.controls,
    muted = _ref.muted,
    onLoadVideo = _ref.onLoadVideo,
    hlsConfig = _ref.hlsConfig,
    timeLimit = _ref.timeLimit,
    timeOffset = _ref.timeOffset,
    _ref$playerRef = _ref.playerRef,
    playerRef = _ref$playerRef === void 0 ? /*#__PURE__*/createRef() : _ref$playerRef,
    src = _ref.src,
    _ref$title = _ref.title,
    title = _ref$title === void 0 ? HLS_DEFAULT_TITLE : _ref$title,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  useInitHlsEffect({
    autoPlay: autoPlay,
    hlsConfig: hlsConfig,
    onLoadVideo: onLoadVideo,
    playerRef: playerRef,
    src: src,
    timeOffset: timeOffset
  });
  var _useTimeLimitCheck = useTimeLimitCheck({
      playerRef: playerRef,
      timeLimit: timeLimit,
      timeOffset: timeOffset
    }),
    startTimeLimitInterval = _useTimeLimitCheck.startTimeLimitInterval,
    stopTimeLimitInterval = _useTimeLimitCheck.stopTimeLimitInterval;
  var nativePlayerProps = {
    autoPlay: autoPlay,
    src: src
  };
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS + "-hlsPlayer",
    children: /*#__PURE__*/_jsx("video", _extends({
      onPlaying: startTimeLimitInterval,
      onPause: stopTimeLimitInterval,
      controls: controls,
      muted: muted,
      className: BASE_CLASS + "-hlsPlayerVideo",
      title: title,
      ref: playerRef
    }, Hls.isSupported() === false ? nativePlayerProps : {}, props))
  });
};
export default HLSPlayer;

==> react-atom-video-player-1.25.0.tgz: package/lib/components/HLSPlayer.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["autoPlay", "controls", "muted", "onLoadVideo", "hlsConfig", "timeLimit", "timeOffset", "playerRef", "src", "title"];
import { createRef, forwardRef } from 'react';
import Hls from 'hls.js';
import PropTypes from 'prop-types';
import useInitHlsEffect from '../hooks/hls/useInitHlsEffect.js';
import useTimeLimitCheck from '../hooks/hls/useTimeLimitCheck.js';
import useImperativeApi from '../hooks/useImperativeApi.js';
import { BASE_CLASS, HLS_DEFAULT_TITLE } from '../settings/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
var HLSPlayer = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var autoPlay = _ref.autoPlay,
    controls = _ref.controls,
    muted = _ref.muted,
    onLoadVideo = _ref.onLoadVideo,
    hlsConfig = _ref.hlsConfig,
    timeLimit = _ref.timeLimit,
    timeOffset = _ref.timeOffset,
    _ref$playerRef = _ref.playerRef,
    playerRef = _ref$playerRef === void 0 ? /*#__PURE__*/createRef() : _ref$playerRef,
    src = _ref.src,
    _ref$title = _ref.title,
    title = _ref$title === void 0 ? HLS_DEFAULT_TITLE : _ref$title,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  useInitHlsEffect({
    autoPlay: autoPlay,
    hlsConfig: hlsConfig,
    onLoadVideo: onLoadVideo,
    playerRef: playerRef,
    src: src,
    timeOffset: timeOffset
  });
  var _useTimeLimitCheck = useTimeLimitCheck({
      playerRef: playerRef,
      timeLimit: timeLimit,
      timeOffset: timeOffset
    }),
    startTimeLimitInterval = _useTimeLimitCheck.startTimeLimitInterval,
    stopTimeLimitInterval = _useTimeLimitCheck.stopTimeLimitInterval;
  useImperativeApi({
    ref: forwardedRef,
    getCurrentTime: function getCurrentTime() {
      return Promise.resolve(playerRef.current.currentTime);
    }
  });
  var nativePlayerProps = {
    autoPlay: autoPlay,
    src: src
  };
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS + "-hlsPlayer",
    children: /*#__PURE__*/_jsx("video", _extends({
      onPlaying: startTimeLimitInterval,
      onPause: stopTimeLimitInterval,
      controls: controls,
      muted: muted,
      className: BASE_CLASS + "-hlsPlayerVideo",
      title: title,
      ref: playerRef
    }, Hls.isSupported() === false ? nativePlayerProps : {}, props))
  });
});
export default HLSPlayer;
